@@ -161,3 +161,24 @@ def object_id():
     def build(*args):
         return ObjectId()
     return build
+
+
+def union(*fns):
+    """Allows the list output of other helper functions to be unioned
+    together in order to be set as a single attribute value. E.g.
+    Unioning the output of n list_of helper calls."""
+    def build(*args):
+        out = []
+        for fn in fns:
+            out += fn(*args)
+        return out
+    return build
+
+
+def one_of(*values):
+    """Provides a function which returns one of the given values at
+    random. Useful for getting a range of different but valid
+    field values on a list of document instances."""
+    def build(*args):
+        return random.choice(values)
+    return build
